==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translation>中心点</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translation>基準点</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translation>ターゲット点</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translation>&amp;R 回転</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translation>回転オプション</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>コピーの数</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;D オリジナルを削除</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>&amp;K オリジナルを維持</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>&amp;M 多重コピー</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translation>&amp;A 角度(a):</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>&amp;a 現在の画層と属性を利用</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translation>中心点</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translation>基準点</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translation>ターゲット点</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translation>&amp;R 回転</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translation>回転オプション</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>コピーの数</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;D オリジナルを削除</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>&amp;K オリジナルを維持</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>&amp;M 多重コピー</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translation>&amp;A 角度(a):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Define angle using mouse cursor</source>
        <translation>マウスカーソルで角度を指定して下さい</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>&amp;a 現在の画層と属性を利用</translation>
    </message>
</context>
</TS>
